@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, List
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -24,11 +24,11 @@ from .literals import (
     MessageFormatTypeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -38,17 +38,23 @@ __all__ = (
     "ActiveContextTimeToLiveTypeDef",
     "ActiveContextTypeDef",
     "ButtonTypeDef",
+    "DeleteSessionRequestRequestTypeDef",
     "DeleteSessionResponseTypeDef",
     "DialogActionTypeDef",
     "GenericAttachmentTypeDef",
+    "GetSessionRequestRequestTypeDef",
     "GetSessionResponseTypeDef",
     "IntentConfidenceTypeDef",
     "IntentSummaryTypeDef",
+    "PostContentRequestRequestTypeDef",
     "PostContentResponseTypeDef",
+    "PostTextRequestRequestTypeDef",
     "PostTextResponseTypeDef",
     "PredictedIntentTypeDef",
+    "PutSessionRequestRequestTypeDef",
     "PutSessionResponseTypeDef",
     "ResponseCardTypeDef",
+    "ResponseMetadataTypeDef",
     "SentimentResponseTypeDef",
 )
 
@@ -78,6 +84,15 @@ ButtonTypeDef = TypedDict(
     },
 )
 
+DeleteSessionRequestRequestTypeDef = TypedDict(
+    "DeleteSessionRequestRequestTypeDef",
+    {
+        "botName": str,
+        "botAlias": str,
+        "userId": str,
+    },
+)
+
 DeleteSessionResponseTypeDef = TypedDict(
     "DeleteSessionResponseTypeDef",
     {
@@ -85,8 +100,8 @@ DeleteSessionResponseTypeDef = TypedDict(
         "botAlias": str,
         "userId": str,
         "sessionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredDialogActionTypeDef = TypedDict(
@@ -125,6 +140,29 @@ GenericAttachmentTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredGetSessionRequestRequestTypeDef = TypedDict(
+    "_RequiredGetSessionRequestRequestTypeDef",
+    {
+        "botName": str,
+        "botAlias": str,
+        "userId": str,
+    },
+)
+_OptionalGetSessionRequestRequestTypeDef = TypedDict(
+    "_OptionalGetSessionRequestRequestTypeDef",
+    {
+        "checkpointLabelFilter": str,
+    },
+    total=False,
+)
+
+
+class GetSessionRequestRequestTypeDef(
+    _RequiredGetSessionRequestRequestTypeDef, _OptionalGetSessionRequestRequestTypeDef
+):
+    pass
+
+
 GetSessionResponseTypeDef = TypedDict(
     "GetSessionResponseTypeDef",
     {
@@ -133,8 +171,8 @@ GetSessionResponseTypeDef = TypedDict(
         "sessionId": str,
         "dialogAction": "DialogActionTypeDef",
         "activeContexts": List["ActiveContextTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 IntentConfidenceTypeDef = TypedDict(
@@ -169,6 +207,34 @@ class IntentSummaryTypeDef(_RequiredIntentSummaryTypeDef, _OptionalIntentSummary
     pass
 
 
+_RequiredPostContentRequestRequestTypeDef = TypedDict(
+    "_RequiredPostContentRequestRequestTypeDef",
+    {
+        "botName": str,
+        "botAlias": str,
+        "userId": str,
+        "contentType": str,
+        "inputStream": Union[bytes, IO[bytes], StreamingBody],
+    },
+)
+_OptionalPostContentRequestRequestTypeDef = TypedDict(
+    "_OptionalPostContentRequestRequestTypeDef",
+    {
+        "sessionAttributes": str,
+        "requestAttributes": str,
+        "accept": str,
+        "activeContexts": str,
+    },
+    total=False,
+)
+
+
+class PostContentRequestRequestTypeDef(
+    _RequiredPostContentRequestRequestTypeDef, _OptionalPostContentRequestRequestTypeDef
+):
+    pass
+
+
 PostContentResponseTypeDef = TypedDict(
     "PostContentResponseTypeDef",
     {
@@ -190,10 +256,36 @@ PostContentResponseTypeDef = TypedDict(
         "botVersion": str,
         "sessionId": str,
         "activeContexts": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredPostTextRequestRequestTypeDef = TypedDict(
+    "_RequiredPostTextRequestRequestTypeDef",
+    {
+        "botName": str,
+        "botAlias": str,
+        "userId": str,
+        "inputText": str,
+    },
+)
+_OptionalPostTextRequestRequestTypeDef = TypedDict(
+    "_OptionalPostTextRequestRequestTypeDef",
+    {
+        "sessionAttributes": Mapping[str, str],
+        "requestAttributes": Mapping[str, str],
+        "activeContexts": Sequence["ActiveContextTypeDef"],
     },
     total=False,
 )
 
+
+class PostTextRequestRequestTypeDef(
+    _RequiredPostTextRequestRequestTypeDef, _OptionalPostTextRequestRequestTypeDef
+):
+    pass
+
+
 PostTextResponseTypeDef = TypedDict(
     "PostTextResponseTypeDef",
     {
@@ -211,8 +303,8 @@ PostTextResponseTypeDef = TypedDict(
         "sessionId": str,
         "botVersion": str,
         "activeContexts": List["ActiveContextTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 PredictedIntentTypeDef = TypedDict(
@@ -225,6 +317,33 @@ PredictedIntentTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredPutSessionRequestRequestTypeDef = TypedDict(
+    "_RequiredPutSessionRequestRequestTypeDef",
+    {
+        "botName": str,
+        "botAlias": str,
+        "userId": str,
+    },
+)
+_OptionalPutSessionRequestRequestTypeDef = TypedDict(
+    "_OptionalPutSessionRequestRequestTypeDef",
+    {
+        "sessionAttributes": Mapping[str, str],
+        "dialogAction": "DialogActionTypeDef",
+        "recentIntentSummaryView": Sequence["IntentSummaryTypeDef"],
+        "accept": str,
+        "activeContexts": Sequence["ActiveContextTypeDef"],
+    },
+    total=False,
+)
+
+
+class PutSessionRequestRequestTypeDef(
+    _RequiredPutSessionRequestRequestTypeDef, _OptionalPutSessionRequestRequestTypeDef
+):
+    pass
+
+
 PutSessionResponseTypeDef = TypedDict(
     "PutSessionResponseTypeDef",
     {
@@ -240,8 +359,8 @@ PutSessionResponseTypeDef = TypedDict(
         "audioStream": StreamingBody,
         "sessionId": str,
         "activeContexts": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ResponseCardTypeDef = TypedDict(
@@ -254,6 +373,17 @@ ResponseCardTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 SentimentResponseTypeDef = TypedDict(
     "SentimentResponseTypeDef",
     {
